This helper expands glue expressions in a path string, creates the directory if it does not already exist, and returns the resulting path.
Examples
tmp_dir <- tempfile("shennong-")
sn_set_path(tmp_dir)
#> /tmp/Rtmp9uKaJP/shennong-1e8e15d82596
This helper expands glue expressions in a path string, creates the directory if it does not already exist, and returns the resulting path.
tmp_dir <- tempfile("shennong-")
sn_set_path(tmp_dir)
#> /tmp/Rtmp9uKaJP/shennong-1e8e15d82596